@@ -1,20 +1,20 @@
 import numpy as np
 import pandas as pd
-import pkg_resources
+import importlib.resources
 import tensorflow as tf
 
 from pathlib import Path
 
-def load_dataset(source, pad, onehot, prefix):
+def load_dataset(source, pad, onehot, package, prefix):
     (xi_train, _), (xi_test, _) = source.load_data()
     return (
-        load_mil(xi_train, pad, onehot, prefix + '_train.csv'),
-        load_mil(xi_test, pad, onehot, prefix + '_test.csv')
+        load_mil(xi_train, pad, onehot, package, prefix + '_train.csv'),
+        load_mil(xi_test, pad, onehot, package, prefix + '_test.csv')
     )
 
-def load_mil(x_orig, pad, onehot, csv):
-    base = Path(pkg_resources.resource_string(__file__, 'csvs'))
-    df = pd.read_csv(base.joinpath('csvs').joinpath(csv))
+def load_mil(x_orig, pad, onehot, package, csv):
+    with importlib.resources.path(f'mil_benchmarks.csvs.{package}', csv) as f:
+        df = pd.read_csv(f)
 
     if pad:
         x = np.zeros((df.shape[0], df.shape[1] - 1) + x_orig[0].shape)
